==> com.liferay.asset.list.web-2.0.78-sources.jar: com/liferay/asset/list/web/internal/constants/AssetListWebKeys.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.asset.list.web.internal.constants;

/**
 * @author Pavel Savinov
 */
public class AssetListWebKeys {

	public static final String ASSET_LIST_DISPLAY_CONTEXT =
		"ASSET_LIST_DISPLAY_CONTEXT";

	public static final String ASSET_LIST_ITEMS_DISPLAY_CONTEXT =
		"ASSET_LIST_ITEMS_DISPLAY_CONTEXT";

	public static final String DDM_INDEXER = "DDM_INDEXER";

	public static final String EDIT_ASSET_LIST_DISPLAY_CONTEXT =
		"EDIT_ASSET_LIST_DISPLAY_CONTEXT";

	public static final String INFO_LIST_PROVIDER_DISPLAY_CONTEXT =
		"INFO_LIST_PROVIDER_DISPLAY_CONTEXT";

	public static final String INFO_LIST_PROVIDER_ITEMS_DISPLAY_CONTEXT =
		"INFO_LIST_PROVIDER_ITEMS_DISPLAY_CONTEXT";

	public static final String ITEM_SELECTOR = "ITEM_SELECTOR";

	public static final String LIST_ITEMS_ACTION_DROPDOWN_ITEMS =
		"LIST_ITEMS_ACTION_DROPDOWN_ITEMS";

	public static final String LIST_ITEMS_DROPDOWN_DEFAULT_EVENT_HANDLER =
		"LIST_ITEMS_DROPDOWN_DEFAULT_EVENT_HANDLER";

}

==> com.liferay.asset.list.web-3.0.60-sources.jar: com/liferay/asset/list/web/internal/constants/AssetListWebKeys.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.asset.list.web.internal.constants;

/**
 * @author Pavel Savinov
 */
public class AssetListWebKeys {

	public static final String ASSET_LIST_DISPLAY_CONTEXT =
		"ASSET_LIST_DISPLAY_CONTEXT";

	public static final String ASSET_LIST_ITEMS_DISPLAY_CONTEXT =
		"ASSET_LIST_ITEMS_DISPLAY_CONTEXT";

	public static final String DDM_INDEXER = "DDM_INDEXER";

	public static final String EDIT_ASSET_LIST_DISPLAY_CONTEXT =
		"EDIT_ASSET_LIST_DISPLAY_CONTEXT";

	public static final String INFO_COLLECTION_PROVIDER_DISPLAY_CONTEXT =
		"INFO_COLLECTION_PROVIDER_DISPLAY_CONTEXT";

	public static final String INFO_COLLECTION_PROVIDER_ITEMS_DISPLAY_CONTEXT =
		"INFO_COLLECTION_PROVIDER_ITEMS_DISPLAY_CONTEXT";

	public static final String ITEM_SELECTOR = "ITEM_SELECTOR";

	public static final String LIST_ITEMS_ACTION_DROPDOWN_ITEMS =
		"LIST_ITEMS_ACTION_DROPDOWN_ITEMS";

	public static final String LIST_ITEMS_DROPDOWN_DEFAULT_EVENT_HANDLER =
		"LIST_ITEMS_DROPDOWN_DEFAULT_EVENT_HANDLER";

	public static final String SELECT_STRUCTURE_FIELD_DISPLAY_CONTEXT =
		"SELECT_STRUCTURE_FIELD_DISPLAY_CONTEXT";

}
